# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.client_system_healthcheck_v2_latest_many_response import ClientSystemHealthcheckV2LatestManyResponse

class TestClientSystemHealthcheckV2LatestManyResponse(unittest.TestCase):
    """ClientSystemHealthcheckV2LatestManyResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ClientSystemHealthcheckV2LatestManyResponse:
        """Test ClientSystemHealthcheckV2LatestManyResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ClientSystemHealthcheckV2LatestManyResponse`
        """
        model = ClientSystemHealthcheckV2LatestManyResponse()
        if include_optional:
            return ClientSystemHealthcheckV2LatestManyResponse(
                data = [
                    neurograph.v1.models.client/system_healthcheck_v2_snapshot.client.SystemHealthcheckV2Snapshot(
                        client_id = '', 
                        client_name = '', 
                        client_uid = '', 
                        error_json = [
                            56
                            ], 
                        error_message = '', 
                        graph_json = [
                            56
                            ], 
                        graph_version = 56, 
                        id = '', 
                        integration_mode = '', 
                        metrics_json = [
                            56
                            ], 
                        org_id = '', 
                        org_name = '', 
                        org_uid = '', 
                        result_success = True, 
                        run_date = '', 
                        status = '', 
                        summary_json = [
                            56
                            ], 
                        ts_finished = '', 
                        ts_started = '', )
                    ],
                error = ''
            )
        else:
            return ClientSystemHealthcheckV2LatestManyResponse(
        )
        """

    def testClientSystemHealthcheckV2LatestManyResponse(self):
        """Test ClientSystemHealthcheckV2LatestManyResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.shopify_compliance_characterization import ShopifyComplianceCharacterization

class TestShopifyComplianceCharacterization(unittest.TestCase):
    """ShopifyComplianceCharacterization unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ShopifyComplianceCharacterization:
        """Test ShopifyComplianceCharacterization
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ShopifyComplianceCharacterization`
        """
        model = ShopifyComplianceCharacterization()
        if include_optional:
            return ShopifyComplianceCharacterization(
                inputs = {
                    'key' : None
                    },
                intent = '',
                notes = [
                    ''
                    ],
                retained_tables = [
                    ''
                    ],
                scope = '',
                summary = '',
                targets = [
                    neurograph.v1.models.shopify/compliance_characterization_target.shopify.ComplianceCharacterizationTarget(
                        action = '', 
                        description = '', 
                        error = '', 
                        query = '', 
                        rows_affected = 56, 
                        status = '', 
                        table = '', )
                    ]
            )
        else:
            return ShopifyComplianceCharacterization(
        )
        """

    def testShopifyComplianceCharacterization(self):
        """Test ShopifyComplianceCharacterization"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.reporting_category_performance_data import ReportingCategoryPerformanceData

class TestReportingCategoryPerformanceData(unittest.TestCase):
    """ReportingCategoryPerformanceData unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ReportingCategoryPerformanceData:
        """Test ReportingCategoryPerformanceData
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ReportingCategoryPerformanceData`
        """
        model = ReportingCategoryPerformanceData()
        if include_optional:
            return ReportingCategoryPerformanceData(
                categories = [
                    neurograph.v1.models.reporting/category_performance_row.reporting.CategoryPerformanceRow(
                        account_avg_affinity = 1.337, 
                        account_avg_conv_rate = 1.337, 
                        account_avg_purchases = 1.337, 
                        account_purchase_pct = 1.337, 
                        affinity_delta = 1.337, 
                        aov = 1.337, 
                        avg_affinity_score = 1.337, 
                        category_name = '', 
                        conv_rate_delta = 1.337, 
                        conversion_rate = 1.337, 
                        engagement_level = '', 
                        is_top_category = True, 
                        persona_purchase_pct = 1.337, 
                        purchase_pct_delta = 1.337, 
                        purchases = 56, 
                        relative_performance = 1.337, 
                        rpv = 1.337, 
                        total_visitors = 56, )
                    ],
                displayed_categories = 56,
                total_categories = 56
            )
        else:
            return ReportingCategoryPerformanceData(
        )
        """

    def testReportingCategoryPerformanceData(self):
        """Test ReportingCategoryPerformanceData"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from neurograph.v1.models.reports_data_source_config import ReportsDataSourceConfig
from neurograph.v1.models.reports_date_range import ReportsDateRange
from typing import Optional, Set
from typing_extensions import Self

class ReportsReportGenerateRequest(BaseModel):
    """
    ReportsReportGenerateRequest
    """ # noqa: E501
    analysis_type: Optional[StrictStr] = None
    brand_context: Optional[Dict[str, Any]] = None
    client_id: Optional[StrictStr] = None
    custom_prompt: Optional[StrictStr] = None
    data_sources: Optional[List[ReportsDataSourceConfig]] = None
    date_range: Optional[ReportsDateRange] = None
    dry_run: Optional[StrictBool] = None
    end_date: Optional[StrictStr] = None
    max_rows: Optional[StrictInt] = None
    name: Optional[StrictStr] = None
    output_format: Optional[StrictStr] = None
    personas: Optional[List[StrictStr]] = None
    report_type: Optional[StrictStr] = None
    start_date: Optional[StrictStr] = None
    __properties: ClassVar[List[str]] = ["analysis_type", "brand_context", "client_id", "custom_prompt", "data_sources", "date_range", "dry_run", "end_date", "max_rows", "name", "output_format", "personas", "report_type", "start_date"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ReportsReportGenerateRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in data_sources (list)
        _items = []
        if self.data_sources:
            for _item_data_sources in self.data_sources:
                if _item_data_sources:
                    _items.append(_item_data_sources.to_dict())
            _dict['data_sources'] = _items
        # override the default output from pydantic by calling `to_dict()` of date_range
        if self.date_range:
            _dict['date_range'] = self.date_range.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ReportsReportGenerateRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "analysis_type": obj.get("analysis_type"),
            "brand_context": obj.get("brand_context"),
            "client_id": obj.get("client_id"),
            "custom_prompt": obj.get("custom_prompt"),
            "data_sources": [ReportsDataSourceConfig.from_dict(_item) for _item in obj["data_sources"]] if obj.get("data_sources") is not None else None,
            "date_range": ReportsDateRange.from_dict(obj["date_range"]) if obj.get("date_range") is not None else None,
            "dry_run": obj.get("dry_run"),
            "end_date": obj.get("end_date"),
            "max_rows": obj.get("max_rows"),
            "name": obj.get("name"),
            "output_format": obj.get("output_format"),
            "personas": obj.get("personas"),
            "report_type": obj.get("report_type"),
            "start_date": obj.get("start_date")
        })
        return _obj





# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.shopify_compliance_deletion_queue_list_response import ShopifyComplianceDeletionQueueListResponse

class TestShopifyComplianceDeletionQueueListResponse(unittest.TestCase):
    """ShopifyComplianceDeletionQueueListResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ShopifyComplianceDeletionQueueListResponse:
        """Test ShopifyComplianceDeletionQueueListResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ShopifyComplianceDeletionQueueListResponse`
        """
        model = ShopifyComplianceDeletionQueueListResponse()
        if include_optional:
            return ShopifyComplianceDeletionQueueListResponse(
                data = [
                    neurograph.v1.models.shopify/compliance_deletion_queue_summary.shopify.ComplianceDeletionQueueSummary(
                        approved_at = '', 
                        client_deletion_status = '', 
                        client_id = '', 
                        client_name = '', 
                        client_uid = '', 
                        id = 56, 
                        myshopify_domain = '', 
                        org_id = '', 
                        org_name = '', 
                        org_uid = '', 
                        queue_status = '', 
                        request_type = '', 
                        requested_at = '', 
                        review_status = '', 
                        scheduled_purge_at = '', 
                        shop_domain = '', 
                        shop_id = 56, )
                    ],
                error = '',
                query = neurograph.v1.models.shopify/compliance_deletion_queue_query.shopify.ComplianceDeletionQueueQuery(
                    limit = 56, 
                    offset = 56, ),
                total_rows = 56
            )
        else:
            return ShopifyComplianceDeletionQueueListResponse(
        )
        """

    def testShopifyComplianceDeletionQueueListResponse(self):
        """Test ShopifyComplianceDeletionQueueListResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.opportunities_opportunity_list_response import OpportunitiesOpportunityListResponse

class TestOpportunitiesOpportunityListResponse(unittest.TestCase):
    """OpportunitiesOpportunityListResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> OpportunitiesOpportunityListResponse:
        """Test OpportunitiesOpportunityListResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `OpportunitiesOpportunityListResponse`
        """
        model = OpportunitiesOpportunityListResponse()
        if include_optional:
            return OpportunitiesOpportunityListResponse(
                data = [
                    neurograph.v1.models.opportunities/opportunity_response.opportunities.OpportunityResponse(
                        action_description = '', 
                        category = '', 
                        client_id = '', 
                        comparison_context = '', 
                        comparison_stat = '', 
                        comparison_type = '', 
                        description = '', 
                        display_order = 56, 
                        effort_level = '', 
                        error = '', 
                        id = '', 
                        name = '', 
                        organization_id = '', 
                        priority_tier = '', 
                        roi_metric = '', 
                        roi_progress = 56, 
                        roi_value = '', 
                        status = '', 
                        subtitle = '', 
                        ts_created = '', 
                        ts_updated = '', )
                    ],
                error = '',
                limit = 56,
                page = 56,
                total = 56,
                total_pages = 56
            )
        else:
            return OpportunitiesOpportunityListResponse(
        )
        """

    def testOpportunitiesOpportunityListResponse(self):
        """Test OpportunitiesOpportunityListResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.reporting_daily_rollup_debug_info import ReportingDailyRollupDebugInfo

class TestReportingDailyRollupDebugInfo(unittest.TestCase):
    """ReportingDailyRollupDebugInfo unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ReportingDailyRollupDebugInfo:
        """Test ReportingDailyRollupDebugInfo
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ReportingDailyRollupDebugInfo`
        """
        model = ReportingDailyRollupDebugInfo()
        if include_optional:
            return ReportingDailyRollupDebugInfo(
                activity_window_days = 56,
                bq_analytics_project = '',
                bq_project = '',
                client_uid = '',
                cohort_start_date = '',
                customers_table = '',
                end_date = '',
                orders_table = '',
                org_uid = '',
                queries = [
                    neurograph.v1.models.reporting/debug_query.reporting.DebugQuery(
                        error = '', 
                        name = '', 
                        sql = '', )
                    ],
                query_time_ms = 56,
                start_date = ''
            )
        else:
            return ReportingDailyRollupDebugInfo(
        )
        """

    def testReportingDailyRollupDebugInfo(self):
        """Test ReportingDailyRollupDebugInfo"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class ShopifyComplianceRequestSummary(BaseModel):
    """
    ShopifyComplianceRequestSummary
    """ # noqa: E501
    client_deletion_status: Optional[StrictStr] = None
    client_id: Optional[StrictStr] = None
    client_name: Optional[StrictStr] = None
    client_uid: Optional[StrictStr] = None
    completed_at: Optional[StrictStr] = None
    customer_email: Optional[StrictStr] = None
    customer_id: Optional[StrictStr] = None
    id: Optional[StrictInt] = None
    myshopify_domain: Optional[StrictStr] = None
    org_id: Optional[StrictStr] = None
    org_name: Optional[StrictStr] = None
    org_uid: Optional[StrictStr] = None
    queue_id: Optional[StrictInt] = None
    queue_status: Optional[StrictStr] = None
    requested_at: Optional[StrictStr] = None
    review_status: Optional[StrictStr] = None
    shop_domain: Optional[StrictStr] = None
    shop_id: Optional[StrictInt] = None
    status: Optional[StrictStr] = None
    type: Optional[StrictStr] = None
    __properties: ClassVar[List[str]] = ["client_deletion_status", "client_id", "client_name", "client_uid", "completed_at", "customer_email", "customer_id", "id", "myshopify_domain", "org_id", "org_name", "org_uid", "queue_id", "queue_status", "requested_at", "review_status", "shop_domain", "shop_id", "status", "type"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ShopifyComplianceRequestSummary from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ShopifyComplianceRequestSummary from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "client_deletion_status": obj.get("client_deletion_status"),
            "client_id": obj.get("client_id"),
            "client_name": obj.get("client_name"),
            "client_uid": obj.get("client_uid"),
            "completed_at": obj.get("completed_at"),
            "customer_email": obj.get("customer_email"),
            "customer_id": obj.get("customer_id"),
            "id": obj.get("id"),
            "myshopify_domain": obj.get("myshopify_domain"),
            "org_id": obj.get("org_id"),
            "org_name": obj.get("org_name"),
            "org_uid": obj.get("org_uid"),
            "queue_id": obj.get("queue_id"),
            "queue_status": obj.get("queue_status"),
            "requested_at": obj.get("requested_at"),
            "review_status": obj.get("review_status"),
            "shop_domain": obj.get("shop_domain"),
            "shop_id": obj.get("shop_id"),
            "status": obj.get("status"),
            "type": obj.get("type")
        })
        return _obj





# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.reporting_price_tolerance_data import ReportingPriceToleranceData

class TestReportingPriceToleranceData(unittest.TestCase):
    """ReportingPriceToleranceData unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ReportingPriceToleranceData:
        """Test ReportingPriceToleranceData
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ReportingPriceToleranceData`
        """
        model = ReportingPriceToleranceData()
        if include_optional:
            return ReportingPriceToleranceData(
                price_distribution = [
                    neurograph.v1.models.reporting/price_bucket.reporting.PriceBucket(
                        is_top_bucket = True, 
                        order_count = 56, 
                        percentage = 1.337, 
                        price_bucket = '', 
                        price_bucket_label = '', )
                    ],
                willingness_to_pay_premium = ''
            )
        else:
            return ReportingPriceToleranceData(
        )
        """

    def testReportingPriceToleranceData(self):
        """Test ReportingPriceToleranceData"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.signal_client_signal_totals import SignalClientSignalTotals

class TestSignalClientSignalTotals(unittest.TestCase):
    """SignalClientSignalTotals unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SignalClientSignalTotals:
        """Test SignalClientSignalTotals
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SignalClientSignalTotals`
        """
        model = SignalClientSignalTotals()
        if include_optional:
            return SignalClientSignalTotals(
                conversions = neurograph.v1.models.signal/conversion_summary.signal.ConversionSummary(
                    api_success_rate = 1.337, 
                    avg_data_completeness = 1.337, 
                    new_customers = 56, 
                    predicted_revenue = 1.337, 
                    prediction_uplift_pct = 1.337, 
                    returning_customers = 56, 
                    returning_pct = 1.337, 
                    total_purchases = 56, 
                    total_revenue = 1.337, ),
                intent = neurograph.v1.models.signal/intent_summary.signal.IntentSummary(
                    avg_high_engagement = 1.337, 
                    avg_low_engagement = 1.337, 
                    avg_medium_engagement = 1.337, 
                    high_conversion_rate = 1.337, 
                    low_conversion_rate = 1.337, 
                    medium_conversion_rate = 1.337, 
                    total_high = 56, 
                    total_low = 56, 
                    total_medium = 56, )
            )
        else:
            return SignalClientSignalTotals(
        )
        """

    def testSignalClientSignalTotals(self):
        """Test SignalClientSignalTotals"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.shopify_compliance_request_record_detail import ShopifyComplianceRequestRecordDetail

class TestShopifyComplianceRequestRecordDetail(unittest.TestCase):
    """ShopifyComplianceRequestRecordDetail unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ShopifyComplianceRequestRecordDetail:
        """Test ShopifyComplianceRequestRecordDetail
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ShopifyComplianceRequestRecordDetail`
        """
        model = ShopifyComplianceRequestRecordDetail()
        if include_optional:
            return ShopifyComplianceRequestRecordDetail(
                actions = [
                    neurograph.v1.models.shopify/compliance_action.shopify.ComplianceAction(
                        action_type = '', 
                        details = [
                            56
                            ], 
                        executed_at = '', 
                        id = 56, 
                        status = '', )
                    ],
                characterization = neurograph.v1.models.shopify/compliance_characterization.shopify.ComplianceCharacterization(
                    inputs = {
                        'key' : None
                        }, 
                    intent = '', 
                    notes = [
                        ''
                        ], 
                    retained_tables = [
                        ''
                        ], 
                    scope = '', 
                    summary = '', 
                    targets = [
                        neurograph.v1.models.shopify/compliance_characterization_target.shopify.ComplianceCharacterizationTarget(
                            action = '', 
                            description = '', 
                            error = '', 
                            query = '', 
                            rows_affected = 56, 
                            status = '', 
                            table = '', )
                        ], ),
                recommendation = neurograph.v1.models.shopify/compliance_recommendation.shopify.ComplianceRecommendation(
                    bigquery_scopes = [
                        ''
                        ], 
                    core_tables = [
                        ''
                        ], 
                    identifiers = neurograph.v1.models.shopify/compliance_identifiers.shopify.ComplianceIdentifiers(
                        client_id = '', 
                        client_partition_keys = [
                            ''
                            ], 
                        client_uid = '', 
                        myshopify_domain = '', 
                        org_id = '', 
                        org_uid = '', 
                        shop_domain = '', 
                        shop_id = 56, ), 
                    immediate_actions = [
                        ''
                        ], 
                    notes = [
                        ''
                        ], ),
                request = neurograph.v1.models.shopify/compliance_request_detail.shopify.ComplianceRequestDetail(
                    completed_at = '', 
                    id = 56, 
                    request_payload = [
                        56
                        ], 
                    requested_at = '', 
                    result_summary = [
                        56
                        ], 
                    status = '', 
                    type = '', ),
                summary = neurograph.v1.models.shopify/compliance_request_summary.shopify.ComplianceRequestSummary(
                    client_deletion_status = '', 
                    client_id = '', 
                    client_name = '', 
                    client_uid = '', 
                    completed_at = '', 
                    customer_email = '', 
                    customer_id = '', 
                    id = 56, 
                    myshopify_domain = '', 
                    org_id = '', 
                    org_name = '', 
                    org_uid = '', 
                    queue_id = 56, 
                    queue_status = '', 
                    requested_at = '', 
                    review_status = '', 
                    shop_domain = '', 
                    shop_id = 56, 
                    status = '', 
                    type = '', )
            )
        else:
            return ShopifyComplianceRequestRecordDetail(
        )
        """

    def testShopifyComplianceRequestRecordDetail(self):
        """Test ShopifyComplianceRequestRecordDetail"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.api.client_metadata_api import ClientMetadataApi


class TestClientMetadataApi(unittest.TestCase):
    """ClientMetadataApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ClientMetadataApi()

    def tearDown(self) -> None:
        pass

    def test_api_v1_client_metadata_client_id_delete(self) -> None:
        """Test case for api_v1_client_metadata_client_id_delete

        Delete a metadata row
        """
        pass

    def test_api_v1_client_metadata_client_id_get(self) -> None:
        """Test case for api_v1_client_metadata_client_id_get

        Get client metadata rows
        """
        pass

    def test_api_v1_client_metadata_client_id_post(self) -> None:
        """Test case for api_v1_client_metadata_client_id_post

        Upsert a client metadata row
        """
        pass

    def test_api_v1_client_metadata_org_uid_client_uid_get(self) -> None:
        """Test case for api_v1_client_metadata_org_uid_client_uid_get

        Get client metadata by organization UID and client UID
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.reporting_daily_metrics_response import ReportingDailyMetricsResponse

class TestReportingDailyMetricsResponse(unittest.TestCase):
    """ReportingDailyMetricsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ReportingDailyMetricsResponse:
        """Test ReportingDailyMetricsResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ReportingDailyMetricsResponse`
        """
        model = ReportingDailyMetricsResponse()
        if include_optional:
            return ReportingDailyMetricsResponse(
                cached = True,
                data = [
                    neurograph.v1.models.reporting/daily_metric.reporting.DailyMetric(
                        aov = 1.337, 
                        avg_ltv_original = 1.337, 
                        cohort_customers = 56, 
                        conversion_rate = 1.337, 
                        customer_conversion_rate = 1.337, 
                        customers_with_purchases = 56, 
                        data_quality_flag = '', 
                        iqr_avg_ltv = 1.337, 
                        ltv_outlier_count = 56, 
                        median_ltv = 1.337, 
                        p25_ltv = 1.337, 
                        p75_ltv = 1.337, 
                        period_revenue = 1.337, 
                        persona_name = '', 
                        persona_seed_id = '', 
                        rpv = 1.337, 
                        rpv_iqr = 1.337, 
                        rpv_median = 1.337, 
                        rpv_outlier_count = 56, 
                        rpv_p25 = 1.337, 
                        rpv_p75 = 1.337, 
                        rpv_trimmed = 1.337, 
                        rpv_winsorized = 1.337, 
                        total_customers = 56, 
                        total_visitors = 56, 
                        trimmed_avg_ltv = 1.337, 
                        visitor_conversion_rate = 1.337, 
                        visitors_with_purchases = 56, 
                        winsorized_avg_ltv = 1.337, )
                    ],
                debug_info = neurograph.v1.models.reporting/daily_rollup_debug_info.reporting.DailyRollupDebugInfo(
                    activity_window_days = 56, 
                    bq_analytics_project = '', 
                    bq_project = '', 
                    client_uid = '', 
                    cohort_start_date = '', 
                    customers_table = '', 
                    end_date = '', 
                    orders_table = '', 
                    org_uid = '', 
                    queries = [
                        neurograph.v1.models.reporting/debug_query.reporting.DebugQuery(
                            error = '', 
                            name = '', 
                            sql = '', )
                        ], 
                    query_time_ms = 56, 
                    start_date = '', ),
                error = '',
                query_time_ms = 56
            )
        else:
            return ReportingDailyMetricsResponse(
        )
        """

    def testReportingDailyMetricsResponse(self):
        """Test ReportingDailyMetricsResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.signal_signal_overview_totals import SignalSignalOverviewTotals

class TestSignalSignalOverviewTotals(unittest.TestCase):
    """SignalSignalOverviewTotals unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SignalSignalOverviewTotals:
        """Test SignalSignalOverviewTotals
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SignalSignalOverviewTotals`
        """
        model = SignalSignalOverviewTotals()
        if include_optional:
            return SignalSignalOverviewTotals(
                avg_match_rate_pct = 1.337,
                conversions = neurograph.v1.models.signal/conversion_totals.signal.ConversionTotals(
                    api_success_rate = 1.337, 
                    avg_data_completeness = 1.337, 
                    persona_coverage = 1.337, 
                    total_conversions = 56, 
                    total_pageview_conversions = 56, 
                    total_purchase_conversions = 56, 
                    visitor_id_coverage = 1.337, ),
                intent_distribution = neurograph.v1.models.signal/intent_distribution.signal.IntentDistribution(
                    high_intent = 56, 
                    high_pct = 1.337, 
                    low_intent = 56, 
                    low_pct = 1.337, 
                    medium_intent = 56, 
                    medium_pct = 1.337, ),
                total_visitors = 56,
                total_with_hem = 56
            )
        else:
            return SignalSignalOverviewTotals(
        )
        """

    def testSignalSignalOverviewTotals(self):
        """Test SignalSignalOverviewTotals"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.reporting_geographic_distribution_data import ReportingGeographicDistributionData

class TestReportingGeographicDistributionData(unittest.TestCase):
    """ReportingGeographicDistributionData unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ReportingGeographicDistributionData:
        """Test ReportingGeographicDistributionData
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ReportingGeographicDistributionData`
        """
        model = ReportingGeographicDistributionData()
        if include_optional:
            return ReportingGeographicDistributionData(
                metro_areas = [
                    neurograph.v1.models.reporting/metro_area.reporting.MetroArea(
                        account_concentration_pct = 1.337, 
                        concentration_pct = 1.337, 
                        customer_count = 56, 
                        delta = 1.337, 
                        is_filler = True, 
                        metro = '', 
                        rank = 56, 
                        relative_delta_pct = 1.337, 
                        state = '', )
                    ],
                other_markets = neurograph.v1.models.reporting/other_markets.reporting.OtherMarkets(
                    concentration_pct = 1.337, 
                    count = 56, 
                    customer_count = 56, ),
                total_metro_count = 56
            )
        else:
            return ReportingGeographicDistributionData(
        )
        """

    def testReportingGeographicDistributionData(self):
        """Test ReportingGeographicDistributionData"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.reporting_purchase_cycle_data import ReportingPurchaseCycleData

class TestReportingPurchaseCycleData(unittest.TestCase):
    """ReportingPurchaseCycleData unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ReportingPurchaseCycleData:
        """Test ReportingPurchaseCycleData
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ReportingPurchaseCycleData`
        """
        model = ReportingPurchaseCycleData()
        if include_optional:
            return ReportingPurchaseCycleData(
                new_customers = neurograph.v1.models.reporting/customer_cycle_metrics.reporting.CustomerCycleMetrics(
                    count = 56, 
                    cycle_days = 56, 
                    display_value = '', 
                    median_days = 56, 
                    tiers = neurograph.v1.models.reporting/cycle_tiers.reporting.CycleTiers(
                        fast = 56, 
                        slow = 56, 
                        typical = 56, ), ),
                returning_customers = neurograph.v1.models.reporting/customer_cycle_metrics.reporting.CustomerCycleMetrics(
                    count = 56, 
                    cycle_days = 56, 
                    display_value = '', 
                    median_days = 56, 
                    tiers = neurograph.v1.models.reporting/cycle_tiers.reporting.CycleTiers(
                        fast = 56, 
                        slow = 56, 
                        typical = 56, ), ),
                summary = neurograph.v1.models.reporting/cycle_summary.reporting.CycleSummary(
                    categories = neurograph.v1.models.reporting/category_summary.reporting.CategorySummary(
                        engaged = 56, 
                        total = 56, ), 
                    last_purchase_days_ago = 56, 
                    total_customers = 56, )
            )
        else:
            return ReportingPurchaseCycleData(
        )
        """

    def testReportingPurchaseCycleData(self):
        """Test ReportingPurchaseCycleData"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from neurograph.v1.models.shopify_compliance_deletion_queue_query import ShopifyComplianceDeletionQueueQuery
from neurograph.v1.models.shopify_compliance_request_summary import ShopifyComplianceRequestSummary
from typing import Optional, Set
from typing_extensions import Self

class ShopifyComplianceRequestListResponse(BaseModel):
    """
    ShopifyComplianceRequestListResponse
    """ # noqa: E501
    data: Optional[List[ShopifyComplianceRequestSummary]] = None
    error: Optional[StrictStr] = None
    query: Optional[ShopifyComplianceDeletionQueueQuery] = None
    total_rows: Optional[StrictInt] = None
    __properties: ClassVar[List[str]] = ["data", "error", "query", "total_rows"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ShopifyComplianceRequestListResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in data (list)
        _items = []
        if self.data:
            for _item_data in self.data:
                if _item_data:
                    _items.append(_item_data.to_dict())
            _dict['data'] = _items
        # override the default output from pydantic by calling `to_dict()` of query
        if self.query:
            _dict['query'] = self.query.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ShopifyComplianceRequestListResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "data": [ShopifyComplianceRequestSummary.from_dict(_item) for _item in obj["data"]] if obj.get("data") is not None else None,
            "error": obj.get("error"),
            "query": ShopifyComplianceDeletionQueueQuery.from_dict(obj["query"]) if obj.get("query") is not None else None,
            "total_rows": obj.get("total_rows")
        })
        return _obj





# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictInt
from typing import Optional
from typing_extensions import Annotated
from neurograph.v1.models.shopify_compliance_approve_request import ShopifyComplianceApproveRequest
from neurograph.v1.models.shopify_compliance_approve_response import ShopifyComplianceApproveResponse
from neurograph.v1.models.shopify_compliance_deletion_queue_detail_response import ShopifyComplianceDeletionQueueDetailResponse
from neurograph.v1.models.shopify_compliance_deletion_queue_list_response import ShopifyComplianceDeletionQueueListResponse
from neurograph.v1.models.shopify_compliance_request_detail_response import ShopifyComplianceRequestDetailResponse
from neurograph.v1.models.shopify_compliance_request_list_response import ShopifyComplianceRequestListResponse

from neurograph.v1.api_client import ApiClient, RequestSerialized
from neurograph.v1.api_response import ApiResponse
from neurograph.v1.rest import RESTResponseType


class ShopifyComplianceApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def api_v1_admin_shopify_compliance_deletions_get(
        self,
        limit: Annotated[Optional[StrictInt], Field(description="Maximum records to return")] = None,
        offset: Annotated[Optional[StrictInt], Field(description="Result offset")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ShopifyComplianceDeletionQueueListResponse:
        """List Shopify compliance deletion queue

        Returns pending and approved Shopify deletion review items.

        :param limit: Maximum records to return
        :type limit: int
        :param offset: Result offset
        :type offset: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_admin_shopify_compliance_deletions_get_serialize(
            limit=limit,
            offset=offset,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ShopifyComplianceDeletionQueueListResponse",
            '503': "ShopifyComplianceDeletionQueueListResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def api_v1_admin_shopify_compliance_deletions_get_with_http_info(
        self,
        limit: Annotated[Optional[StrictInt], Field(description="Maximum records to return")] = None,
        offset: Annotated[Optional[StrictInt], Field(description="Result offset")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ShopifyComplianceDeletionQueueListResponse]:
        """List Shopify compliance deletion queue

        Returns pending and approved Shopify deletion review items.

        :param limit: Maximum records to return
        :type limit: int
        :param offset: Result offset
        :type offset: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_admin_shopify_compliance_deletions_get_serialize(
            limit=limit,
            offset=offset,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ShopifyComplianceDeletionQueueListResponse",
            '503': "ShopifyComplianceDeletionQueueListResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def api_v1_admin_shopify_compliance_deletions_get_without_preload_content(
        self,
        limit: Annotated[Optional[StrictInt], Field(description="Maximum records to return")] = None,
        offset: Annotated[Optional[StrictInt], Field(description="Result offset")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """List Shopify compliance deletion queue

        Returns pending and approved Shopify deletion review items.

        :param limit: Maximum records to return
        :type limit: int
        :param offset: Result offset
        :type offset: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_admin_shopify_compliance_deletions_get_serialize(
            limit=limit,
            offset=offset,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ShopifyComplianceDeletionQueueListResponse",
            '503': "ShopifyComplianceDeletionQueueListResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _api_v1_admin_shopify_compliance_deletions_get_serialize(
        self,
        limit,
        offset,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if limit is not None:
            
            _query_params.append(('limit', limit))
            
        if offset is not None:
            
            _query_params.append(('offset', offset))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'ApiKeyAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/v1/admin/shopify/compliance/deletions',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def api_v1_admin_shopify_compliance_deletions_queue_id_approve_post(
        self,
        queue_id: Annotated[StrictInt, Field(description="Queue ID")],
        request: Annotated[Optional[ShopifyComplianceApproveRequest], Field(description="Optional approval note")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ShopifyComplianceApproveResponse:
        """Approve Shopify compliance deletion review

        Marks a deletion queue item as approved for later purge execution.

        :param queue_id: Queue ID (required)
        :type queue_id: int
        :param request: Optional approval note
        :type request: ShopifyComplianceApproveRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_admin_shopify_compliance_deletions_queue_id_approve_post_serialize(
            queue_id=queue_id,
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ShopifyComplianceApproveResponse",
            '400': "ShopifyComplianceApproveResponse",
            '404': "ShopifyComplianceApproveResponse",
            '409': "ShopifyComplianceApproveResponse",
            '503': "ShopifyComplianceApproveResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def api_v1_admin_shopify_compliance_deletions_queue_id_approve_post_with_http_info(
        self,
        queue_id: Annotated[StrictInt, Field(description="Queue ID")],
        request: Annotated[Optional[ShopifyComplianceApproveRequest], Field(description="Optional approval note")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ShopifyComplianceApproveResponse]:
        """Approve Shopify compliance deletion review

        Marks a deletion queue item as approved for later purge execution.

        :param queue_id: Queue ID (required)
        :type queue_id: int
        :param request: Optional approval note
        :type request: ShopifyComplianceApproveRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_admin_shopify_compliance_deletions_queue_id_approve_post_serialize(
            queue_id=queue_id,
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ShopifyComplianceApproveResponse",
            '400': "ShopifyComplianceApproveResponse",
            '404': "ShopifyComplianceApproveResponse",
            '409': "ShopifyComplianceApproveResponse",
            '503': "ShopifyComplianceApproveResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def api_v1_admin_shopify_compliance_deletions_queue_id_approve_post_without_preload_content(
        self,
        queue_id: Annotated[StrictInt, Field(description="Queue ID")],
        request: Annotated[Optional[ShopifyComplianceApproveRequest], Field(description="Optional approval note")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Approve Shopify compliance deletion review

        Marks a deletion queue item as approved for later purge execution.

        :param queue_id: Queue ID (required)
        :type queue_id: int
        :param request: Optional approval note
        :type request: ShopifyComplianceApproveRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_admin_shopify_compliance_deletions_queue_id_approve_post_serialize(
            queue_id=queue_id,
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ShopifyComplianceApproveResponse",
            '400': "ShopifyComplianceApproveResponse",
            '404': "ShopifyComplianceApproveResponse",
            '409': "ShopifyComplianceApproveResponse",
            '503': "ShopifyComplianceApproveResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _api_v1_admin_shopify_compliance_deletions_queue_id_approve_post_serialize(
        self,
        queue_id,
        request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if queue_id is not None:
            _path_params['queue_id'] = queue_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if request is not None:
            _body_params = request


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'ApiKeyAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/api/v1/admin/shopify/compliance/deletions/{queue_id}/approve',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def api_v1_admin_shopify_compliance_deletions_queue_id_get(
        self,
        queue_id: Annotated[StrictInt, Field(description="Queue ID")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ShopifyComplianceDeletionQueueDetailResponse:
        """Get Shopify compliance deletion review detail

        Returns queue item detail, action log, and purge-scope recommendation.

        :param queue_id: Queue ID (required)
        :type queue_id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_admin_shopify_compliance_deletions_queue_id_get_serialize(
            queue_id=queue_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ShopifyComplianceDeletionQueueDetailResponse",
            '400': "ShopifyComplianceDeletionQueueDetailResponse",
            '404': "ShopifyComplianceDeletionQueueDetailResponse",
            '503': "ShopifyComplianceDeletionQueueDetailResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def api_v1_admin_shopify_compliance_deletions_queue_id_get_with_http_info(
        self,
        queue_id: Annotated[StrictInt, Field(description="Queue ID")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ShopifyComplianceDeletionQueueDetailResponse]:
        """Get Shopify compliance deletion review detail

        Returns queue item detail, action log, and purge-scope recommendation.

        :param queue_id: Queue ID (required)
        :type queue_id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_admin_shopify_compliance_deletions_queue_id_get_serialize(
            queue_id=queue_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ShopifyComplianceDeletionQueueDetailResponse",
            '400': "ShopifyComplianceDeletionQueueDetailResponse",
            '404': "ShopifyComplianceDeletionQueueDetailResponse",
            '503': "ShopifyComplianceDeletionQueueDetailResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def api_v1_admin_shopify_compliance_deletions_queue_id_get_without_preload_content(
        self,
        queue_id: Annotated[StrictInt, Field(description="Queue ID")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get Shopify compliance deletion review detail

        Returns queue item detail, action log, and purge-scope recommendation.

        :param queue_id: Queue ID (required)
        :type queue_id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_admin_shopify_compliance_deletions_queue_id_get_serialize(
            queue_id=queue_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ShopifyComplianceDeletionQueueDetailResponse",
            '400': "ShopifyComplianceDeletionQueueDetailResponse",
            '404': "ShopifyComplianceDeletionQueueDetailResponse",
            '503': "ShopifyComplianceDeletionQueueDetailResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _api_v1_admin_shopify_compliance_deletions_queue_id_get_serialize(
        self,
        queue_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if queue_id is not None:
            _path_params['queue_id'] = queue_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'ApiKeyAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/v1/admin/shopify/compliance/deletions/{queue_id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def api_v1_admin_shopify_compliance_requests_get(
        self,
        limit: Annotated[Optional[StrictInt], Field(description="Maximum records to return")] = None,
        offset: Annotated[Optional[StrictInt], Field(description="Result offset")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ShopifyComplianceRequestListResponse:
        """List Shopify compliance requests

        Returns all Shopify compliance requests across data_request, customer_redact, and shop_redact.

        :param limit: Maximum records to return
        :type limit: int
        :param offset: Result offset
        :type offset: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_admin_shopify_compliance_requests_get_serialize(
            limit=limit,
            offset=offset,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ShopifyComplianceRequestListResponse",
            '503': "ShopifyComplianceRequestListResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def api_v1_admin_shopify_compliance_requests_get_with_http_info(
        self,
        limit: Annotated[Optional[StrictInt], Field(description="Maximum records to return")] = None,
        offset: Annotated[Optional[StrictInt], Field(description="Result offset")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ShopifyComplianceRequestListResponse]:
        """List Shopify compliance requests

        Returns all Shopify compliance requests across data_request, customer_redact, and shop_redact.

        :param limit: Maximum records to return
        :type limit: int
        :param offset: Result offset
        :type offset: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_admin_shopify_compliance_requests_get_serialize(
            limit=limit,
            offset=offset,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ShopifyComplianceRequestListResponse",
            '503': "ShopifyComplianceRequestListResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def api_v1_admin_shopify_compliance_requests_get_without_preload_content(
        self,
        limit: Annotated[Optional[StrictInt], Field(description="Maximum records to return")] = None,
        offset: Annotated[Optional[StrictInt], Field(description="Result offset")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """List Shopify compliance requests

        Returns all Shopify compliance requests across data_request, customer_redact, and shop_redact.

        :param limit: Maximum records to return
        :type limit: int
        :param offset: Result offset
        :type offset: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_admin_shopify_compliance_requests_get_serialize(
            limit=limit,
            offset=offset,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ShopifyComplianceRequestListResponse",
            '503': "ShopifyComplianceRequestListResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _api_v1_admin_shopify_compliance_requests_get_serialize(
        self,
        limit,
        offset,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if limit is not None:
            
            _query_params.append(('limit', limit))
            
        if offset is not None:
            
            _query_params.append(('offset', offset))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'ApiKeyAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/v1/admin/shopify/compliance/requests',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def api_v1_admin_shopify_compliance_requests_request_id_get(
        self,
        request_id: Annotated[StrictInt, Field(description="Compliance request ID")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ShopifyComplianceRequestDetailResponse:
        """Get Shopify compliance request detail

        Returns one Shopify compliance request with action log and recommendation.

        :param request_id: Compliance request ID (required)
        :type request_id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_admin_shopify_compliance_requests_request_id_get_serialize(
            request_id=request_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ShopifyComplianceRequestDetailResponse",
            '400': "ShopifyComplianceRequestDetailResponse",
            '404': "ShopifyComplianceRequestDetailResponse",
            '503': "ShopifyComplianceRequestDetailResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def api_v1_admin_shopify_compliance_requests_request_id_get_with_http_info(
        self,
        request_id: Annotated[StrictInt, Field(description="Compliance request ID")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ShopifyComplianceRequestDetailResponse]:
        """Get Shopify compliance request detail

        Returns one Shopify compliance request with action log and recommendation.

        :param request_id: Compliance request ID (required)
        :type request_id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_admin_shopify_compliance_requests_request_id_get_serialize(
            request_id=request_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ShopifyComplianceRequestDetailResponse",
            '400': "ShopifyComplianceRequestDetailResponse",
            '404': "ShopifyComplianceRequestDetailResponse",
            '503': "ShopifyComplianceRequestDetailResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def api_v1_admin_shopify_compliance_requests_request_id_get_without_preload_content(
        self,
        request_id: Annotated[StrictInt, Field(description="Compliance request ID")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get Shopify compliance request detail

        Returns one Shopify compliance request with action log and recommendation.

        :param request_id: Compliance request ID (required)
        :type request_id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_admin_shopify_compliance_requests_request_id_get_serialize(
            request_id=request_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ShopifyComplianceRequestDetailResponse",
            '400': "ShopifyComplianceRequestDetailResponse",
            '404': "ShopifyComplianceRequestDetailResponse",
            '503': "ShopifyComplianceRequestDetailResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _api_v1_admin_shopify_compliance_requests_request_id_get_serialize(
        self,
        request_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if request_id is not None:
            _path_params['request_id'] = request_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'ApiKeyAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/v1/admin/shopify/compliance/requests/{request_id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.reporting_product_affinity_row import ReportingProductAffinityRow

class TestReportingProductAffinityRow(unittest.TestCase):
    """ReportingProductAffinityRow unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ReportingProductAffinityRow:
        """Test ReportingProductAffinityRow
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ReportingProductAffinityRow`
        """
        model = ReportingProductAffinityRow()
        if include_optional:
            return ReportingProductAffinityRow(
                avg_engagement_score = 1.337,
                avg_lifetime_value = 1.337,
                avg_view_count = 1.337,
                client_partition_key = '',
                confidence_level = 56,
                conversion_rate = 1.337,
                entity_id = '',
                normalized_affinity_score = 1.337,
                partition_date = '',
                product_handle = '',
                product_id = '',
                product_name = '',
                product_type = '',
                raw_affinity_score = 1.337,
                score_penalty = 1.337,
                total_conversions = 56,
                total_visitors = 56,
                weighted_conversion_score = 1.337
            )
        else:
            return ReportingProductAffinityRow(
        )
        """

    def testReportingProductAffinityRow(self):
        """Test ReportingProductAffinityRow"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.shopify_compliance_deletion_queue_detail_response import ShopifyComplianceDeletionQueueDetailResponse

class TestShopifyComplianceDeletionQueueDetailResponse(unittest.TestCase):
    """ShopifyComplianceDeletionQueueDetailResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ShopifyComplianceDeletionQueueDetailResponse:
        """Test ShopifyComplianceDeletionQueueDetailResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ShopifyComplianceDeletionQueueDetailResponse`
        """
        model = ShopifyComplianceDeletionQueueDetailResponse()
        if include_optional:
            return ShopifyComplianceDeletionQueueDetailResponse(
                data = neurograph.v1.models.shopify/compliance_deletion_queue_detail.shopify.ComplianceDeletionQueueDetail(
                    actions = [
                        neurograph.v1.models.shopify/compliance_action.shopify.ComplianceAction(
                            action_type = '', 
                            details = [
                                56
                                ], 
                            executed_at = '', 
                            id = 56, 
                            status = '', )
                        ], 
                    characterization = neurograph.v1.models.shopify/compliance_characterization.shopify.ComplianceCharacterization(
                        inputs = {
                            'key' : None
                            }, 
                        intent = '', 
                        notes = [
                            ''
                            ], 
                        retained_tables = [
                            ''
                            ], 
                        scope = '', 
                        summary = '', 
                        targets = [
                            neurograph.v1.models.shopify/compliance_characterization_target.shopify.ComplianceCharacterizationTarget(
                                action = '', 
                                description = '', 
                                error = '', 
                                query = '', 
                                rows_affected = 56, 
                                status = '', 
                                table = '', )
                            ], ), 
                    recommendation = neurograph.v1.models.shopify/compliance_recommendation.shopify.ComplianceRecommendation(
                        bigquery_scopes = [
                            ''
                            ], 
                        core_tables = [
                            ''
                            ], 
                        identifiers = neurograph.v1.models.shopify/compliance_identifiers.shopify.ComplianceIdentifiers(
                            client_id = '', 
                            client_partition_keys = [
                                ''
                                ], 
                            client_uid = '', 
                            myshopify_domain = '', 
                            org_id = '', 
                            org_uid = '', 
                            shop_domain = '', 
                            shop_id = 56, ), 
                        immediate_actions = [
                            ''
                            ], ), 
                    request = neurograph.v1.models.shopify/compliance_request_detail.shopify.ComplianceRequestDetail(
                        completed_at = '', 
                        id = 56, 
                        request_payload = [
                            56
                            ], 
                        requested_at = '', 
                        result_summary = [
                            56
                            ], 
                        status = '', 
                        type = '', ), 
                    summary = neurograph.v1.models.shopify/compliance_deletion_queue_summary.shopify.ComplianceDeletionQueueSummary(
                        approved_at = '', 
                        client_deletion_status = '', 
                        client_id = '', 
                        client_name = '', 
                        client_uid = '', 
                        id = 56, 
                        myshopify_domain = '', 
                        org_id = '', 
                        org_name = '', 
                        org_uid = '', 
                        queue_status = '', 
                        request_type = '', 
                        requested_at = '', 
                        review_status = '', 
                        scheduled_purge_at = '', 
                        shop_domain = '', 
                        shop_id = 56, ), ),
                error = ''
            )
        else:
            return ShopifyComplianceDeletionQueueDetailResponse(
        )
        """

    def testShopifyComplianceDeletionQueueDetailResponse(self):
        """Test ShopifyComplianceDeletionQueueDetailResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.client_get_many_response import ClientGetManyResponse

class TestClientGetManyResponse(unittest.TestCase):
    """ClientGetManyResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ClientGetManyResponse:
        """Test ClientGetManyResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ClientGetManyResponse`
        """
        model = ClientGetManyResponse()
        if include_optional:
            return ClientGetManyResponse(
                data = [
                    neurograph.v1.models.client/client.client.Client(
                        id = '', 
                        is_active = True, 
                        name = '', 
                        org_id = '', 
                        personas_reviewed = True, 
                        pixel_snippets = [
                            neurograph.v1.models.db/pixel_snippet.db.PixelSnippet(
                                id = 56, 
                                name = '', 
                                snippet = '', )
                            ], 
                        ts_created = 56, 
                        ts_updated = 56, 
                        uid = '', 
                        urls = [
                            neurograph.v1.models.db/client_url.db.ClientUrl(
                                client_id = 'cli_12345', 
                                customer_environment = '', 
                                id = 56, 
                                is_active = True, 
                                url = 'example.com', )
                            ], )
                    ],
                error = '',
                query = neurograph.v1.models.client/query.client.Query(
                    limit = 56, 
                    offset = 56, 
                    org_id = '', 
                    uid = '', ),
                total_rows = 56
            )
        else:
            return ClientGetManyResponse(
        )
        """

    def testClientGetManyResponse(self):
        """Test ClientGetManyResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# flake8: noqa

# import apis into api package
from neurograph.v1.api.admin_api import AdminApi
from neurograph.v1.api.authentication_api import AuthenticationApi
from neurograph.v1.api.client_api import ClientApi
from neurograph.v1.api.client_metadata_api import ClientMetadataApi
from neurograph.v1.api.dagster_api import DagsterApi
from neurograph.v1.api.knowledge_api import KnowledgeApi
from neurograph.v1.api.knowledge_extract_api import KnowledgeExtractApi
from neurograph.v1.api.lookup_api import LookupApi
from neurograph.v1.api.opportunities_api import OpportunitiesApi
from neurograph.v1.api.organization_api import OrganizationApi
from neurograph.v1.api.organization_metadata_api import OrganizationMetadataApi
from neurograph.v1.api.persona_api import PersonaApi
from neurograph.v1.api.pixel_api import PixelApi
from neurograph.v1.api.reporting_api import ReportingApi
from neurograph.v1.api.reports_api import ReportsApi
from neurograph.v1.api.shopify_api import ShopifyApi
from neurograph.v1.api.shopify_compliance_api import ShopifyComplianceApi
from neurograph.v1.api.signal_api import SignalApi
from neurograph.v1.api.user_api import UserApi
from neurograph.v1.api.workbench_api import WorkbenchApi




# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.api.shopify_api import ShopifyApi


class TestShopifyApi(unittest.TestCase):
    """ShopifyApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ShopifyApi()

    def tearDown(self) -> None:
        pass

    def test_api_v1_shopify_stores_client_client_id_get(self) -> None:
        """Test case for api_v1_shopify_stores_client_client_id_get

        Get Shopify store for client
        """
        pass

    def test_api_v1_shopify_stores_shop_id_associate_delete(self) -> None:
        """Test case for api_v1_shopify_stores_shop_id_associate_delete

        Remove Shopify store association
        """
        pass

    def test_api_v1_shopify_stores_shop_id_associate_post(self) -> None:
        """Test case for api_v1_shopify_stores_shop_id_associate_post

        Associate unmatched Shopify store to a client
        """
        pass

    def test_api_v1_shopify_stores_shop_id_get(self) -> None:
        """Test case for api_v1_shopify_stores_shop_id_get

        Get Shopify store by ID
        """
        pass

    def test_api_v1_shopify_stores_unmatched_get(self) -> None:
        """Test case for api_v1_shopify_stores_unmatched_get

        List unmatched Shopify stores
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.organizations_gamma_theme_response import OrganizationsGammaThemeResponse

class TestOrganizationsGammaThemeResponse(unittest.TestCase):
    """OrganizationsGammaThemeResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> OrganizationsGammaThemeResponse:
        """Test OrganizationsGammaThemeResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `OrganizationsGammaThemeResponse`
        """
        model = OrganizationsGammaThemeResponse()
        if include_optional:
            return OrganizationsGammaThemeResponse(
                error = '',
                success = True,
                theme = neurograph.v1.models.organizations/gamma_theme_settings.organizations.GammaThemeSettings(
                    colors = neurograph.v1.models.colors.colors(), 
                    design = neurograph.v1.models.design.design(), 
                    fonts = neurograph.v1.models.fonts.fonts(), 
                    reasoning = '', )
            )
        else:
            return OrganizationsGammaThemeResponse(
        )
        """

    def testOrganizationsGammaThemeResponse(self):
        """Test OrganizationsGammaThemeResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.shopify_get_unmatched_stores_response import ShopifyGetUnmatchedStoresResponse

class TestShopifyGetUnmatchedStoresResponse(unittest.TestCase):
    """ShopifyGetUnmatchedStoresResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ShopifyGetUnmatchedStoresResponse:
        """Test ShopifyGetUnmatchedStoresResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ShopifyGetUnmatchedStoresResponse`
        """
        model = ShopifyGetUnmatchedStoresResponse()
        if include_optional:
            return ShopifyGetUnmatchedStoresResponse(
                data = [
                    neurograph.v1.models.shopify/store_summary.shopify.StoreSummary(
                        client_id = '', 
                        domain = '', 
                        id = 56, 
                        ingested_at = '', 
                        myshopify_domain = '', 
                        name = '', 
                        shopify_updated_at_ms = 56, 
                        updated_at_ms = 56, )
                    ],
                error = '',
                query = neurograph.v1.models.shopify/store_query.shopify.StoreQuery(
                    limit = 56, 
                    offset = 56, ),
                total_rows = 56
            )
        else:
            return ShopifyGetUnmatchedStoresResponse(
        )
        """

    def testShopifyGetUnmatchedStoresResponse(self):
        """Test ShopifyGetUnmatchedStoresResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from neurograph.v1.models.pgtype_text import PgtypeText
from neurograph.v1.models.pgtype_timestamp import PgtypeTimestamp
from typing import Optional, Set
from typing_extensions import Self

class DbKnowledgeOrder(BaseModel):
    """
    DbKnowledgeOrder
    """ # noqa: E501
    billing_address_hash: Optional[PgtypeText] = None
    billing_address_json: Optional[List[StrictInt]] = None
    cancelled_at: Optional[PgtypeTimestamp] = None
    channel: Optional[StrictStr] = None
    client_id: Optional[StrictStr] = None
    closed_at: Optional[PgtypeTimestamp] = None
    currency: Optional[StrictStr] = None
    customer_entity_id: Optional[PgtypeText] = None
    discount_amount: Optional[Union[StrictFloat, StrictInt]] = None
    email_at_order: Optional[PgtypeText] = None
    entity_id: Optional[StrictStr] = None
    ext_order_id: Optional[PgtypeText] = None
    ext_order_number: Optional[PgtypeText] = None
    ext_store_id: Optional[PgtypeText] = None
    financial_status: Optional[StrictStr] = None
    fulfillment_status: Optional[StrictStr] = None
    phone_at_order: Optional[PgtypeText] = None
    placed_at: Optional[PgtypeTimestamp] = None
    shipping_address_hash: Optional[PgtypeText] = None
    shipping_address_json: Optional[List[StrictInt]] = None
    shipping_amount: Optional[Union[StrictFloat, StrictInt]] = None
    source_name: Optional[StrictStr] = None
    status: Optional[StrictStr] = None
    store_entity_id: Optional[PgtypeText] = None
    subtotal_amount: Optional[Union[StrictFloat, StrictInt]] = None
    tax_amount: Optional[Union[StrictFloat, StrictInt]] = None
    total_amount: Optional[Union[StrictFloat, StrictInt]] = None
    __properties: ClassVar[List[str]] = ["billing_address_hash", "billing_address_json", "cancelled_at", "channel", "client_id", "closed_at", "currency", "customer_entity_id", "discount_amount", "email_at_order", "entity_id", "ext_order_id", "ext_order_number", "ext_store_id", "financial_status", "fulfillment_status", "phone_at_order", "placed_at", "shipping_address_hash", "shipping_address_json", "shipping_amount", "source_name", "status", "store_entity_id", "subtotal_amount", "tax_amount", "total_amount"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of DbKnowledgeOrder from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of billing_address_hash
        if self.billing_address_hash:
            _dict['billing_address_hash'] = self.billing_address_hash.to_dict()
        # override the default output from pydantic by calling `to_dict()` of cancelled_at
        if self.cancelled_at:
            _dict['cancelled_at'] = self.cancelled_at.to_dict()
        # override the default output from pydantic by calling `to_dict()` of closed_at
        if self.closed_at:
            _dict['closed_at'] = self.closed_at.to_dict()
        # override the default output from pydantic by calling `to_dict()` of customer_entity_id
        if self.customer_entity_id:
            _dict['customer_entity_id'] = self.customer_entity_id.to_dict()
        # override the default output from pydantic by calling `to_dict()` of email_at_order
        if self.email_at_order:
            _dict['email_at_order'] = self.email_at_order.to_dict()
        # override the default output from pydantic by calling `to_dict()` of ext_order_id
        if self.ext_order_id:
            _dict['ext_order_id'] = self.ext_order_id.to_dict()
        # override the default output from pydantic by calling `to_dict()` of ext_order_number
        if self.ext_order_number:
            _dict['ext_order_number'] = self.ext_order_number.to_dict()
        # override the default output from pydantic by calling `to_dict()` of ext_store_id
        if self.ext_store_id:
            _dict['ext_store_id'] = self.ext_store_id.to_dict()
        # override the default output from pydantic by calling `to_dict()` of phone_at_order
        if self.phone_at_order:
            _dict['phone_at_order'] = self.phone_at_order.to_dict()
        # override the default output from pydantic by calling `to_dict()` of placed_at
        if self.placed_at:
            _dict['placed_at'] = self.placed_at.to_dict()
        # override the default output from pydantic by calling `to_dict()` of shipping_address_hash
        if self.shipping_address_hash:
            _dict['shipping_address_hash'] = self.shipping_address_hash.to_dict()
        # override the default output from pydantic by calling `to_dict()` of store_entity_id
        if self.store_entity_id:
            _dict['store_entity_id'] = self.store_entity_id.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of DbKnowledgeOrder from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "billing_address_hash": PgtypeText.from_dict(obj["billing_address_hash"]) if obj.get("billing_address_hash") is not None else None,
            "billing_address_json": obj.get("billing_address_json"),
            "cancelled_at": PgtypeTimestamp.from_dict(obj["cancelled_at"]) if obj.get("cancelled_at") is not None else None,
            "channel": obj.get("channel"),
            "client_id": obj.get("client_id"),
            "closed_at": PgtypeTimestamp.from_dict(obj["closed_at"]) if obj.get("closed_at") is not None else None,
            "currency": obj.get("currency"),
            "customer_entity_id": PgtypeText.from_dict(obj["customer_entity_id"]) if obj.get("customer_entity_id") is not None else None,
            "discount_amount": obj.get("discount_amount"),
            "email_at_order": PgtypeText.from_dict(obj["email_at_order"]) if obj.get("email_at_order") is not None else None,
            "entity_id": obj.get("entity_id"),
            "ext_order_id": PgtypeText.from_dict(obj["ext_order_id"]) if obj.get("ext_order_id") is not None else None,
            "ext_order_number": PgtypeText.from_dict(obj["ext_order_number"]) if obj.get("ext_order_number") is not None else None,
            "ext_store_id": PgtypeText.from_dict(obj["ext_store_id"]) if obj.get("ext_store_id") is not None else None,
            "financial_status": obj.get("financial_status"),
            "fulfillment_status": obj.get("fulfillment_status"),
            "phone_at_order": PgtypeText.from_dict(obj["phone_at_order"]) if obj.get("phone_at_order") is not None else None,
            "placed_at": PgtypeTimestamp.from_dict(obj["placed_at"]) if obj.get("placed_at") is not None else None,
            "shipping_address_hash": PgtypeText.from_dict(obj["shipping_address_hash"]) if obj.get("shipping_address_hash") is not None else None,
            "shipping_address_json": obj.get("shipping_address_json"),
            "shipping_amount": obj.get("shipping_amount"),
            "source_name": obj.get("source_name"),
            "status": obj.get("status"),
            "store_entity_id": PgtypeText.from_dict(obj["store_entity_id"]) if obj.get("store_entity_id") is not None else None,
            "subtotal_amount": obj.get("subtotal_amount"),
            "tax_amount": obj.get("tax_amount"),
            "total_amount": obj.get("total_amount")
        })
        return _obj





# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.api.organization_api import OrganizationApi


class TestOrganizationApi(unittest.TestCase):
    """OrganizationApi unit test stubs"""

    def setUp(self) -> None:
        self.api = OrganizationApi()

    def tearDown(self) -> None:
        pass

    def test_api_v1_organizations_branding_generate_gamma_theme_post(self) -> None:
        """Test case for api_v1_organizations_branding_generate_gamma_theme_post

        Generate Gamma theme settings from brand colors using AI
        """
        pass

    def test_api_v1_organizations_branding_generate_post(self) -> None:
        """Test case for api_v1_organizations_branding_generate_post

        Generate branding from screenshot using AI
        """
        pass

    def test_api_v1_organizations_branding_generate_screenshot_url_post(self) -> None:
        """Test case for api_v1_organizations_branding_generate_screenshot_url_post

        Generate signed ScreenshotOne URL for website
        """
        pass

    def test_api_v1_organizations_branding_generate_tokens_post(self) -> None:
        """Test case for api_v1_organizations_branding_generate_tokens_post

        Generate Theme Tokens
        """
        pass

    def test_api_v1_organizations_branding_post(self) -> None:
        """Test case for api_v1_organizations_branding_post

        Set an Organization's Branding
        """
        pass

    def test_api_v1_organizations_branding_presets_apply_post(self) -> None:
        """Test case for api_v1_organizations_branding_presets_apply_post

        Apply Theme Preset to Organization Branding
        """
        pass

    def test_api_v1_organizations_branding_presets_category_category_get(self) -> None:
        """Test case for api_v1_organizations_branding_presets_category_category_get

        Get Theme Presets by Category
        """
        pass

    def test_api_v1_organizations_branding_presets_get(self) -> None:
        """Test case for api_v1_organizations_branding_presets_get

        Get Theme Presets
        """
        pass

    def test_api_v1_organizations_branding_presets_id_delete(self) -> None:
        """Test case for api_v1_organizations_branding_presets_id_delete

        Delete Theme Preset
        """
        pass

    def test_api_v1_organizations_branding_presets_post(self) -> None:
        """Test case for api_v1_organizations_branding_presets_post

        Create Theme Preset
        """
        pass

    def test_api_v1_organizations_branding_presets_put(self) -> None:
        """Test case for api_v1_organizations_branding_presets_put

        Update Theme Preset
        """
        pass

    def test_api_v1_organizations_branding_presets_recommendations_get(self) -> None:
        """Test case for api_v1_organizations_branding_presets_recommendations_get

        Get Preset Recommendations
        """
        pass

    def test_api_v1_organizations_branding_presets_search_get(self) -> None:
        """Test case for api_v1_organizations_branding_presets_search_get

        Search Theme Presets
        """
        pass

    def test_api_v1_organizations_branding_preview_post(self) -> None:
        """Test case for api_v1_organizations_branding_preview_post

        Preview Branding
        """
        pass

    def test_api_v1_organizations_branding_rollback_post(self) -> None:
        """Test case for api_v1_organizations_branding_rollback_post

        Rollback Branding to Previous Version
        """
        pass

    def test_api_v1_organizations_branding_test_accessibility_post(self) -> None:
        """Test case for api_v1_organizations_branding_test_accessibility_post

        Test Branding Accessibility
        """
        pass

    def test_api_v1_organizations_branding_validate_post(self) -> None:
        """Test case for api_v1_organizations_branding_validate_post

        Validate Branding Colors
        """
        pass

    def test_api_v1_organizations_get(self) -> None:
        """Test case for api_v1_organizations_get

        Get Organizations
        """
        pass

    def test_api_v1_organizations_id_branding_delete(self) -> None:
        """Test case for api_v1_organizations_id_branding_delete

        Delete an Organization's Branding
        """
        pass

    def test_api_v1_organizations_id_branding_get(self) -> None:
        """Test case for api_v1_organizations_id_branding_get

        Get an Organization's Branding
        """
        pass

    def test_api_v1_organizations_id_branding_history_get(self) -> None:
        """Test case for api_v1_organizations_id_branding_history_get

        Get Branding History
        """
        pass

    def test_api_v1_organizations_id_branding_history_version_get(self) -> None:
        """Test case for api_v1_organizations_id_branding_history_version_get

        Get Specific Branding Version
        """
        pass

    def test_api_v1_organizations_id_branding_put(self) -> None:
        """Test case for api_v1_organizations_id_branding_put

        Update an Organization's Branding
        """
        pass

    def test_api_v1_organizations_id_branding_tokens_get(self) -> None:
        """Test case for api_v1_organizations_id_branding_tokens_get

        Get Cached Branding Tokens
        """
        pass

    def test_api_v1_organizations_org_id_get(self) -> None:
        """Test case for api_v1_organizations_org_id_get

        Get Organization by ID or UID
        """
        pass

    def test_api_v1_organizations_org_id_users_get(self) -> None:
        """Test case for api_v1_organizations_org_id_users_get

        Organization's assigned users and their permissions
        """
        pass

    def test_api_v1_organizations_post(self) -> None:
        """Test case for api_v1_organizations_post

        Create an Organization
        """
        pass

    def test_api_v1_organizations_put(self) -> None:
        """Test case for api_v1_organizations_put

        Update an Organization
        """
        pass

    def test_api_v1_organizations_workbench_post(self) -> None:
        """Test case for api_v1_organizations_workbench_post

        Set Organization's Workbench Version
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.shopify_get_store_response import ShopifyGetStoreResponse

class TestShopifyGetStoreResponse(unittest.TestCase):
    """ShopifyGetStoreResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ShopifyGetStoreResponse:
        """Test ShopifyGetStoreResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ShopifyGetStoreResponse`
        """
        model = ShopifyGetStoreResponse()
        if include_optional:
            return ShopifyGetStoreResponse(
                data = neurograph.v1.models.shopify/store_detail.shopify.StoreDetail(
                    client_id = '', 
                    domain = '', 
                    id = 56, 
                    ingested_at = '', 
                    myshopify_domain = '', 
                    name = '', 
                    shopify_updated_at_ms = 56, 
                    updated_at_ms = 56, ),
                error = ''
            )
        else:
            return ShopifyGetStoreResponse(
        )
        """

    def testShopifyGetStoreResponse(self):
        """Test ShopifyGetStoreResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
